[waffle] [PATCH 2/2] waffle: replace GL with OpenGL

Jordan Justen jordan.l.justen at intel.com
Wed Apr 16 17:19:28 PDT 2014


This replaced cases of GL with OpenGL in documents, comments
and printed strings.

Signed-off-by: Jordan Justen <jordan.l.justen at intel.com>
Cc: Brian Paul <brianp at vmware.com>
Cc: Chad Versace <chad.versace at linux.intel.com>
---
Chad,

I think the comment in src/waffle/linux/linux_dl.c might need
to be updated (removed?) in a separate patch.

 README.txt                              | 28 ++++++++++++++--------------
 debian/control                          | 10 +++++-----
 doxygen/Doxyfile                        |  2 +-
 examples/gl_basic.c                     | 18 +++++++++---------
 examples/simple-x11-egl.c               | 10 +++++-----
 man/waffle.7.xml                        | 14 +++++++-------
 man/waffle_get_proc_address.3.xml       |  2 +-
 man/waffle_is_extension_in_string.3.xml |  2 +-
 src/utils/wflinfo.c                     | 16 ++++++++--------
 src/waffle/egl/wegl_config.c            |  2 +-
 src/waffle/glx/glx_config.c             |  2 +-
 src/waffle/linux/linux_dl.c             | 10 +++++-----
 tests/functional/gl_basic_test.c        |  6 +++---
 waffle.pc.in                            |  2 +-
 14 files changed, 62 insertions(+), 62 deletions(-)

diff --git a/README.txt b/README.txt
index 6703638..b9f3ee4 100644
--- a/README.txt
+++ b/README.txt
@@ -1,19 +1,19 @@
-Waffle - a library for selecting GL API and window system at runtime
+Waffle - a library for selecting an OpenGL API and window system at runtime
 
 Summary
 =======
 
-Waffle is a cross-platform library that allows one to defer selection of GL
-API and of window system until runtime. For example, on Linux, Waffle enables
-an application to select X11/EGL with an OpenGL 3.3 core profile, Wayland
-with OpenGL ES2, and other window system / API combinations.
+Waffle is a cross-platform library that allows one to defer selection of an
+OpenGL API and of window system until runtime. For example, on Linux, Waffle
+enables an application to select X11/EGL with an OpenGL 3.3 core profile,
+Wayland with OpenGL ES2, and other window system / API combinations.
 
-Waffle's immediate goal is to enable Piglit [1] to test multiple GL flavors in
-a cross-platform way, and to allow each Piglit test to choose its GL API and
-window system at runtime. A future goal is to enable the ability to record
-(with another tool such APITrace [2]) an application's GL calls on one
-operating system or window system, and then replay that trace on a different
-system.
+Waffle's immediate goal is to enable Piglit [1] to test multiple OpenGL
+flavors in a cross-platform way, and to allow each Piglit test to choose its
+OpenGL API and window system at runtime. A future goal is to enable the
+ability to record (with another tool such APITrace [2]) an application's
+OpenGL calls on one operating system or window system, and then replay
+that trace on a different system.
 
 For more information, visit to Waffle's website.
 
@@ -154,6 +154,6 @@ install libwaffle into $HOME/lib, use the following cmake invocation:
     make check
     make install
 
-Calling `make check` only runs unittests that do not access the native GL
-platform. To run additional functional tests, which do access the native GL
-platform, call `make check-func`.
+Calling `make check` only runs unittests that do not access the native OpenGL
+platform. To run additional functional tests, which do access the native
+OpenGL platform, call `make check-func`.
diff --git a/debian/control b/debian/control
index a3e2566..151395b 100644
--- a/debian/control
+++ b/debian/control
@@ -23,7 +23,7 @@ Package: libwaffle-1
 Architecture: any
 Depends: ${shlibs:Depends}, ${misc:Pre-Depends}, ${misc:Depends}
 Description: Waffle library utilities
- A library for selecting GL API and window system at runtime
+ A library for selecting an OpenGL API and window system at runtime
 
 Package: libwaffle-dev
 Architecture: any
@@ -31,7 +31,7 @@ Section: libdevel
 Depends: libwaffle-1 (= ${binary:Version})
 Suggests: libwaffle-doc
 Description: Waffle library utilities
- A library for selecting GL API and window system at runtime
+ A library for selecting an OpenGL API and window system at runtime
  .
  This package provides the development environment for compiling
  programs against the waffle library.
@@ -40,7 +40,7 @@ Package: libwaffle-doc
 Architecture: all
 Section: doc
 Description: Waffle library utilities
- A library for selecting GL API and window system at runtime
+ A library for selecting an OpenGL API and window system at runtime
  .
  This package provides the documentation files for the waffle
  library.
@@ -50,8 +50,8 @@ Architecture: any
 Section: utils
 Depends: libwaffle-1 (= ${binary:Version})
 Description: Waffle library utilities
- A library for selecting GL API and window system at runtime
+ A library for selecting an OpenGL API and window system at runtime
  .
  This package contains waffle utilities.
- * wflinfo: Creates a GL context and prints information about
+ * wflinfo: Creates an OpenGL context and prints information about
             the created context.
diff --git a/doxygen/Doxyfile b/doxygen/Doxyfile
index 009a899..1d3f0cc 100644
--- a/doxygen/Doxyfile
+++ b/doxygen/Doxyfile
@@ -38,7 +38,7 @@ PROJECT_NUMBER         =
 # for a project that appears at the top of each page and should give viewer
 # a quick idea about the purpose of the project. Keep the description short.
 
-PROJECT_BRIEF          = "a library for selecting GL API and window system at runtime"
+PROJECT_BRIEF          = "a library for selecting an OpenGL API and window system at runtime"
 
 # With the PROJECT_LOGO tag one can specify an logo or icon that is
 # included in the documentation. The maximum height of the logo should not
diff --git a/examples/simple-x11-egl.c b/examples/simple-x11-egl.c
index 1732e7a..975e25b 100644
--- a/examples/simple-x11-egl.c
+++ b/examples/simple-x11-egl.c
@@ -1,4 +1,4 @@
-// Copyright 2012 Intel Corporation
+// Copyright 2012, 2014 Intel Corporation
 //
 // All rights reserved.
 //
@@ -26,9 +26,9 @@
 /// @file simple-x11-egl.c
 ///
 /// This little example program renders to an X11 window with EGL and an OpenGL
-/// ES2 context.  The program does not include any GL headers and does not need
-/// to link to libGL. It declares the needed GL symbols itself and obtains the
-/// GL functions with waffle_dl_sym().
+/// ES2 context.  The program does not include any OpenGL headers and does not
+/// need to link to libGL. It declares the needed OpenGL symbols itself and
+/// obtains the OpenGL functions with waffle_dl_sym().
 ///
 /// This example is too simple; it does not perform proper error checking. For
 /// a complete example with error checking, see gl_basic.c.
@@ -90,7 +90,7 @@ main()
         exit(EXIT_FAILURE);
     }
 
-    // Get GL functions.
+    // Get OpenGL functions.
     glClearColor = waffle_dl_sym(WAFFLE_DL_OPENGL_ES2, "glClearColor");
     glClear = waffle_dl_sym(WAFFLE_DL_OPENGL_ES2, "glClear");
 
diff --git a/man/waffle.7.xml b/man/waffle.7.xml
index f983329..078b613 100644
--- a/man/waffle.7.xml
+++ b/man/waffle.7.xml
@@ -3,7 +3,7 @@
   "http://www.oasis-open.org/docbook/xml/4.2/docbookx.dtd">
 
 <!--
-  Copyright Intel 2012
+  Copyright Intel 2012 - 2014
 
   This manual page is licensed under the Creative Commons Attribution-ShareAlike 3.0 United States License (CC BY-SA 3.0
   US). To view a copy of this license, visit http://creativecommons.org.license/by-sa/3.0/us.
@@ -22,7 +22,7 @@
 
   <refnamediv>
     <refname>waffle</refname>
-    <refpurpose>a library for selecting GL API and window system at runtime</refpurpose>
+    <refpurpose>a library for selecting an OpenGL API and window system at runtime</refpurpose>
   </refnamediv>
 
   <refentryinfo>
@@ -45,7 +45,7 @@ Link with -lwaffle-1.
     <title>Description</title>
 
     <para>
-      Waffle is a cross-platform library that allows one to defer selection of GL API and of window system until
+      Waffle is a cross-platform library that allows one to defer selection of an OpenGL API and of window system until
       runtime. For example, on Linux, Waffle enables an application to select X11/EGL with an OpenGL 3.3 core profile,
       Wayland with OpenGL ES2, and other window system / API combinations.
     </para>
@@ -54,11 +54,11 @@ Link with -lwaffle-1.
       Waffle's immediate goal is to enable
       <ulink url="http://cgit.freedesktop.org/piglit/tree/README">Piglit</ulink>,
       <ulink url="http://mesa3d.org">Mesa</ulink>'s OpenGL test suite,
-      to test multiple GL flavors in a cross-platform way, and to allow each Piglit test to choose its GL API and window
-      system at runtime. A future goal is to enable the ability to record,
+      to test multiple OpenGL flavors in a cross-platform way, and to allow each Piglit test to choose its OpenGL API
+      and window system at runtime. A future goal is to enable the ability to record,
       with another tool such as <ulink url="http://github.com/apitrace/apitrace#readme">APITrace</ulink>,
-      an application's GL calls on one operating system or window system, and then replay that trace on a different
-      system.
+      an application's OpenGL calls on one operating system or window system, and then replay that trace on a
+      different system.
     </para>
 
     <para>
diff --git a/man/waffle_get_proc_address.3.xml b/man/waffle_get_proc_address.3.xml
index a609894..36b9ea2 100644
--- a/man/waffle_get_proc_address.3.xml
+++ b/man/waffle_get_proc_address.3.xml
@@ -22,7 +22,7 @@
 
   <refnamediv>
     <refname>waffle_get_proc_address</refname>
-    <refpurpose>Query address of GL functions</refpurpose>
+    <refpurpose>Query address of OpenGL functions</refpurpose>
   </refnamediv>
 
   <refentryinfo>
diff --git a/man/waffle_is_extension_in_string.3.xml b/man/waffle_is_extension_in_string.3.xml
index 2328c5a..0aa215a 100644
--- a/man/waffle_is_extension_in_string.3.xml
+++ b/man/waffle_is_extension_in_string.3.xml
@@ -67,7 +67,7 @@
 
             in the format returned by <code>glGetString(GL_EXTENSIONS)</code>.
 
-            Note that this function is not restricted to the GL extension string;
+            Note that this function is not restricted to the OpenGL extension string;
 
             it can also be used on the GLX and EGL extension strings.
           </para>
diff --git a/src/waffle/egl/wegl_config.c b/src/waffle/egl/wegl_config.c
index 2c1bc1c..1e2d4ee 100644
--- a/src/waffle/egl/wegl_config.c
+++ b/src/waffle/egl/wegl_config.c
@@ -59,7 +59,7 @@ check_context_attrs(struct wegl_display *dpy,
             if (attrs->context_full_version != 10 && !dpy->KHR_create_context) {
                 wcore_errorf(WAFFLE_ERROR_UNSUPPORTED_ON_PLATFORM,
                              "KHR_EXT_create_context is required in order to "
-                             "request a GL version not equal to the default "
+                             "request an OpenGL version not equal to the default "
                              "value 1.0");
                 return false;
             }
diff --git a/src/waffle/glx/glx_config.c b/src/waffle/glx/glx_config.c
index 98949e8..56744d4 100644
--- a/src/waffle/glx/glx_config.c
+++ b/src/waffle/glx/glx_config.c
@@ -73,7 +73,7 @@ glx_config_check_context_attrs(struct glx_display *dpy,
             if (attrs->context_full_version != 10 && !dpy->ARB_create_context) {
                 wcore_errorf(WAFFLE_ERROR_UNSUPPORTED_ON_PLATFORM,
                              "GLX_ARB_create_context is required in order to "
-                             "request a GL version not equal to the default "
+                             "request an OpenGL version not equal to the default "
                              "value 1.0");
                 return false;
             }
diff --git a/src/waffle/linux/linux_dl.c b/src/waffle/linux/linux_dl.c
index 4f6a8b6..8a154f1 100644
--- a/src/waffle/linux/linux_dl.c
+++ b/src/waffle/linux/linux_dl.c
@@ -59,12 +59,12 @@ linux_dl_get_name(int32_t waffle_dl)
         case WAFFLE_DL_OPENGL_ES2:
         case WAFFLE_DL_OPENGL_ES3:
             // TODO(chadv): Update the libGLESv2 soversion number to match
-            // shipping GLES3 libraries.
+            // shipping OpenGL ES 3.0 libraries.
             //
-            // Currently (2012-11-11), no vendor ships GLES3. I expect that
-            // vendors will increment the minor soversion of libGLESv2 if it
-            // supports GLES3, which would aid Waffle in detecting the
-            // platform's GLES3 support.
+            // Currently (2012-11-11), no vendor ships OpenGL ES 3.0. I
+            // expect that vendors will increment the minor soversion of
+            // libGLESv2 if it supports OpenGL ES 3.0, which would aid
+            // Waffle in detecting the platform's OpenGL ES 3.0 support.
             return "libGLESv2.so";
         default:
             wcore_error_internal("waffle_dl has bad value %#x", waffle_dl);
diff --git a/tests/functional/gl_basic_test.c b/tests/functional/gl_basic_test.c
index 268656a..6a93de1 100644
--- a/tests/functional/gl_basic_test.c
+++ b/tests/functional/gl_basic_test.c
@@ -24,7 +24,7 @@
 // OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 /// @file
-/// @brief Test basic GL rendering with all platform/gl_api combinations.
+/// @brief Test basic OpenGL rendering with all platform/gl_api combinations.
 ///
 /// Each test does the following:
 ///     1. Initialize waffle with a platform and gl_api.
@@ -82,7 +82,7 @@ static uint8_t pixels[4 * WINDOW_WIDTH * WINDOW_HEIGHT];
     } while (0)
 
 /// @}
-/// @defgroup GL declarations
+/// @defgroup OpenGL declarations
 /// @{
 
 typedef unsigned int        GLenum;
@@ -291,7 +291,7 @@ gl_basic_draw__(struct gl_basic_draw_args__ args)
         }
     }
 
-    // Get GL functions.
+    // Get OpenGL functions.
     ASSERT_TRUE(glClear         = waffle_dl_sym(libgl, "glClear"));
     ASSERT_TRUE(glClearColor    = waffle_dl_sym(libgl, "glClearColor"));
     ASSERT_TRUE(glGetError      = waffle_dl_sym(libgl, "glGetError"));
diff --git a/waffle.pc.in b/waffle.pc.in
index 3f60a8b..b6e4725 100644
--- a/waffle.pc.in
+++ b/waffle.pc.in
@@ -4,7 +4,7 @@ libdir=@CMAKE_INSTALL_FULL_LIBDIR@
 includedir=@CMAKE_INSTALL_FULL_INCLUDEDIR@
 
 Name: @waffle_libname@
-Description: a library for selecting GL API and window system at runtime
+Description: a library for selecting an OpenGL API and window system at runtime
 Version: @waffle_version@
 Libs: -L${libdir} -l at waffle_libname@
 Cflags: -I${includedir}/@waffle_libname@
diff --git a/examples/gl_basic.c b/examples/gl_basic.c
index ce922b0..59422ef 100644
--- a/examples/gl_basic.c
+++ b/examples/gl_basic.c
@@ -1,4 +1,4 @@
-// Copyright 2012 Intel Corporation
+// Copyright 2012 - 2014 Intel Corporation
 //
 // All rights reserved.
 //
@@ -24,12 +24,12 @@
 // OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 /// @file gl_basic.c
 /// @brief Do some basic GL rendering using Waffle.
 ///
 /// This example does the following:
 ///     1. Dynamically choose the platform and GL API according to command
 ///        line arguments.
 ///     2. Create a window and GL context.
 ///     3. Fill the window with red, then green, then blue, sleeping between
 ///        each buffer swap.
 
@@ -166,7 +166,7 @@ error_get_gl_symbol(const char *name)
 }
 
 /// @}
-/// @defgroup GL decalrations
+/// @defgroup OpenGL decalrations
 /// @{
 
 typedef float GLclampf;
@@ -301,7 +301,7 @@ parse_args(int argc, char *argv[], struct options *opts)
                 ok = enum_map_translate_str(context_api_map, optarg,
                                             &opts->context_api);
                 if (!ok) {
-                    usage_error_printf("'%s' is not a valid API for a GL "
+                    usage_error_printf("'%s' is not a valid API for an OpenGL "
                                        "context", optarg);
                 }
                 break;
@@ -312,7 +312,7 @@ parse_args(int argc, char *argv[], struct options *opts)
 
                 match_count = sscanf(optarg, "%d.%d", &major, &minor);
                 if (match_count != 2) {
-                    usage_error_printf("'%s' is not a valid GL version",
+                    usage_error_printf("'%s' is not a valid OpenGL version",
                                        optarg);
                 }
                 opts->context_version = 10 * major + minor;
@@ -326,7 +326,7 @@ parse_args(int argc, char *argv[], struct options *opts)
                 } else if (strcmp(optarg, "compat") == 0) {
                     opts->context_profile = WAFFLE_CONTEXT_COMPATIBILITY_PROFILE;
                 } else {
-                    usage_error_printf("'%s' is not a valid GL profile",
+                    usage_error_printf("'%s' is not a valid OpenGL profile",
                                        optarg);
                 }
                 break;
@@ -24,12 +24,12 @@
 
 /// @file gl_basic.c
-/// @brief Do some basic GL rendering using Waffle.
+/// @brief Do some basic OpenGL rendering using Waffle.
 ///
 /// This example does the following:
@@ -24,12 +24,12 @@
 ///
 /// This example does the following:
-///     1. Dynamically choose the platform and GL API according to command
-///        line arguments.
-///     2. Create a window and GL context.
+///     1. Dynamically choose the platform and OpenGL API according to
+///        command line arguments.
+///     2. Create a window and OpenGL context.
 ///     3. Fill the window with red, then green, then blue, sleeping between
 ///        each buffer swap.
diff --git a/src/utils/wflinfo.c b/src/utils/wflinfo.c
index 8ab18a6..560a97b 100644
--- a/src/utils/wflinfo.c
+++ b/src/utils/wflinfo.c
@@ -24,12 +24,12 @@
 // OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 /// @file wflinfo.c
 /// @brief Print GL info using Waffle.
 ///
 /// This program does the following:
 ///     1. Dynamically choose the platform and GL API according to command
 ///        line arguments.
 ///     2. Create a GL context.
 ///     3. Print information about the context.
 
 #define WAFFLE_API_VERSION 0x0103
@@ -183,7 +183,7 @@ error_get_gl_symbol(const char *name)
 }
 
 /// @}
-/// @defgroup GL decalrations
+/// @defgroup OpenGL decalrations
 /// @{
 
 typedef float GLclampf;
@@ -338,7 +338,7 @@ parse_args(int argc, char *argv[], struct options *opts)
                 ok = enum_map_translate_str(context_api_map, optarg,
                                             &opts->context_api);
                 if (!ok) {
-                    usage_error_printf("'%s' is not a valid API for a GL "
+                    usage_error_printf("'%s' is not a valid API for an OpenGL "
                                        "context", optarg);
                 }
                 break;
@@ -349,7 +349,7 @@ parse_args(int argc, char *argv[], struct options *opts)
 
                 match_count = sscanf(optarg, "%d.%d", &major, &minor);
                 if (match_count != 2) {
-                    usage_error_printf("'%s' is not a valid GL version",
+                    usage_error_printf("'%s' is not a valid OpenGL version",
                                        optarg);
                 }
                 opts->context_version = 10 * major + minor;
@@ -363,7 +363,7 @@ parse_args(int argc, char *argv[], struct options *opts)
                 } else if (strcmp(optarg, "compat") == 0) {
                     opts->context_profile = WAFFLE_CONTEXT_COMPATIBILITY_PROFILE;
                 } else {
-                    usage_error_printf("'%s' is not a valid GL profile",
+                    usage_error_printf("'%s' is not a valid OpenGL profile",
                                        optarg);
                 }
                 break;
@@ -24,12 +24,12 @@
 
 /// @file wflinfo.c
-/// @brief Print GL info using Waffle.
+/// @brief Print OpenGL info using Waffle.
 ///
 /// This program does the following:
@@ -24,12 +24,12 @@
 ///
 /// This program does the following:
-///     1. Dynamically choose the platform and GL API according to command
-///        line arguments.
-///     2. Create a GL context.
+///     1. Dynamically choose the platform and OpenGL API according to
+///        command line arguments.
+///     2. Create an OpenGL context.
 ///     3. Print information about the context.
 
-- 
1.9.2



More information about the waffle mailing list